bayespy.inference.vmp.nodes.gaussian.GaussianGammaDistribution.random
=====================================================================

.. currentmodule:: bayespy.inference.vmp.nodes.gaussian

.. automethod:: GaussianGammaDistribution.random